import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule
from dosage.util import getQueryParams

class LethalDoses(BasicComicModule):
    latestUrl = 'http://www.lethaldoses.com/index2.php'
    imageUrl = 'http://www.lethaldoses.com/index2.php?strip_id=%s'
    imageSearch = re.compile(r'<img src=\'(/index2\.php\?do_command=show_strip&strip_id=\d+.+?)\'', re.IGNORECASE)
    prevSearch = re.compile(r'<a href=[\'"](/?index2\.php\?strip_id=\d+)[\'"]><img.+?src=[\'"]\./images/nav_prev.gif[\'"]', re.IGNORECASE)
    help = 'Index format: n (unpadded)'

    def getFilename(self, imageUrl, pageUrl):
        return getQueryParams(imageUrl)['strip_id'][0]
